<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label=" 问卷标题 " prop="svytitle">
        <el-input
          v-model="queryParams.svytitle"
          placeholder="请输入 问卷标题 "
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label=" 总得分 " prop="totalscore">
        <el-input
          v-model="queryParams.totalscore"
          placeholder="请输入 总得分 "
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label=" 机构ID " prop="orgid">
        <el-input
          v-model="queryParams.orgid"
          placeholder="请输入 机构ID "
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label=" 是否异常 " prop="isabnormal">
        <el-input
          v-model="queryParams.isabnormal"
          placeholder="请输入 是否异常 "
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['smartor:svyfinish:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['smartor:svyfinish:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['smartor:svyfinish:remove']"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['smartor:svyfinish:export']"
        >导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="svyfinishList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label=" 自增ID " align="center" prop="id" />
      <el-table-column label=" 患者ID " align="center" prop="patid" />
      <el-table-column label=" 关联方案ID " align="center" prop="schemeid" />
      <el-table-column label=" 问卷标题 " align="center" prop="svytitle" />
      <el-table-column label=" 问卷ID " align="center" prop="svyid" />
      <el-table-column label=" 总得分 " align="center" prop="totalscore" />
      <el-table-column label=" 反馈结果内容 " align="center" prop="resultcontent" />
      <el-table-column label=" 机构ID " align="center" prop="orgid" />
      <el-table-column label=" 展示得分 " align="center" prop="isshowscore" />
      <el-table-column label=" 计划ID " align="center" prop="schemeplanid" />
      <el-table-column label=" 任务ID " align="center" prop="schemetaskid" />
      <el-table-column label=" 是否异常 " align="center" prop="isabnormal" />
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['smartor:svyfinish:edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['smartor:svyfinish:remove']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>
    
    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改问卷最终结果对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label=" 患者ID " prop="patid">
          <el-input v-model="form.patid" placeholder="请输入 患者ID " />
        </el-form-item>
        <el-form-item label=" 关联方案ID " prop="schemeid">
          <el-input v-model="form.schemeid" placeholder="请输入 关联方案ID " />
        </el-form-item>
        <el-form-item label=" 问卷标题 " prop="svytitle">
          <el-input v-model="form.svytitle" placeholder="请输入 问卷标题 " />
        </el-form-item>
        <el-form-item label=" 问卷ID " prop="svyid">
          <el-input v-model="form.svyid" placeholder="请输入 问卷ID " />
        </el-form-item>
        <el-form-item label=" 总得分 " prop="totalscore">
          <el-input v-model="form.totalscore" placeholder="请输入 总得分 " />
        </el-form-item>
        <el-form-item label=" 反馈结果内容 ">
          <editor v-model="form.resultcontent" :min-height="192"/>
        </el-form-item>
        <el-form-item label=" 机构ID " prop="orgid">
          <el-input v-model="form.orgid" placeholder="请输入 机构ID " />
        </el-form-item>
        <el-form-item label=" 展示得分 " prop="isshowscore">
          <el-input v-model="form.isshowscore" placeholder="请输入 展示得分 " />
        </el-form-item>
        <el-form-item label=" 计划ID " prop="schemeplanid">
          <el-input v-model="form.schemeplanid" placeholder="请输入 计划ID " />
        </el-form-item>
        <el-form-item label=" 任务ID " prop="schemetaskid">
          <el-input v-model="form.schemetaskid" placeholder="请输入 任务ID " />
        </el-form-item>
        <el-form-item label=" 是否异常 " prop="isabnormal">
          <el-input v-model="form.isabnormal" placeholder="请输入 是否异常 " />
        </el-form-item>
        <el-form-item label=" 删除标记 " prop="delFlag">
          <el-input v-model="form.delFlag" placeholder="请输入 删除标记 " />
        </el-form-item>
        <el-form-item label=" 上传标记 " prop="isupload">
          <el-input v-model="form.isupload" placeholder="请输入 上传标记 " />
        </el-form-item>
        <el-form-item label=" 上传时间 " prop="uploadTime">
          <el-date-picker clearable
            v-model="form.uploadTime"
            type="date"
            value-format="yyyy-MM-dd"
            placeholder="请选择 上传时间 ">
          </el-date-picker>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listSvyfinish, getSvyfinish, delSvyfinish, addSvyfinish, updateSvyfinish } from "@/api/smartor/svyfinish";

export default {
  name: "Svyfinish",
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 问卷最终结果表格数据
      svyfinishList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        svytitle: null,
        totalscore: null,
        orgid: null,
        isabnormal: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        delFlag: [
          { required: true, message: " 删除标记 不能为空", trigger: "blur" }
        ],
        isupload: [
          { required: true, message: " 上传标记 不能为空", trigger: "blur" }
        ],
      }
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询问卷最终结果列表 */
    getList() {
      this.loading = true;
      listSvyfinish(this.queryParams).then(response => {
        this.svyfinishList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        patid: null,
        schemeid: null,
        svytitle: null,
        svyid: null,
        totalscore: null,
        resultcontent: null,
        orgid: null,
        isshowscore: null,
        schemeplanid: null,
        schemetaskid: null,
        isabnormal: null,
        delFlag: null,
        createBy: null,
        createTime: null,
        updateBy: null,
        updateTime: null,
        isupload: null,
        uploadTime: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加问卷最终结果";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getSvyfinish(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改问卷最终结果";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateSvyfinish(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addSvyfinish(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除问卷最终结果编号为"' + ids + '"的数据项？').then(function() {
        return delSvyfinish(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('smartor/svyfinish/export', {
        ...this.queryParams
      }, `svyfinish_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
